==> Newdistns_1.0.tar.gz: Newdistns/man/Newdistns-package.Rd <==
\name{Newdistns-package}
\alias{Newdistns-package}
\alias{Newdistns}
\docType{package}
\title{
Computes pdf, cdf, quantile and random numbers for 19 general families of distributions
}
\description{Computes the probability density function, cumulative distribution function, quantile function, random numbers for the following general families of  distributions (each family defined in terms of an arbitrary cdf G): Marshall Olkin G distributions due to Marshall and Olkin  (1997),
exponentiated G distributions due to Gupta et al. (1998), beta G distributions due to Eugene et al. (2002), gamma G distributions due to Zografos and Balakrishnan (2009), Kumaraswamy G distributions due to Cordeiro and Castro (2011), generalized beta G distributions due to Alexander et al. (2012),
beta extended G distributions due to Cordeiro et al. (2012), gamma G distributions due to Ristic and Balakrishnan (2012), gamma uniform G distributions due to Torabi and Montazeri (2012), beta exponential G distributions due to Alzaatreh et al. (2013), Weibull G distributions also due to Alzaatreh et al. (2013), log gamma G I distributions due to Amini et al. (2013), log gamma G II distributions also due to Amini et al. (2013), exponentiated generalized G distributions due to Cordeiro et al. (2013), exponentiated Kumaraswamy G distributions due to Lemonte et al. (2013), geometric exponential Poisson G distributions due to Nadarajah et al. (2013a), truncated-exponential skew-symmetric G distributions due to Nadarajah et al. (2013b), modified beta G distributions due to Nadarajah et al. (2013c), and exponentiated exponential Poisson G distributions due to Ristic and Nadarajah (2013).}
\details{
\tabular{ll}{
Package: \tab Newdistns\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2013-8-9\cr
License: \tab GPL(>=2)
}
probability density function, cumulative distribution function, quantile function, random numbers
}
\author{Saralees Nadarajah

Maintainer: Saralees Nadarajah <Saralees.Nadarajah@manchester.ac.uk>
}
\references{C. Alexander, G. M. Cordeiro, E. M. M. Ortega, Generalized beta-generated distributions, Computational Statistics and Data Analysis 56 (2012) 1880-1897

A. Alzaatreh, C. Lee, F. Famoye, A new method for generating families of continuous distributions, METRON 71 (2013) 63-79

M. Amini, S. M. T. K. MirMostafaee, J. Ahmadi, Log-gamma-generated families of distributions, Statistics, 2013, doi: 10.1080/02331888.2012.748775

G. M. Cordeiro, M. Castro, A new family of generalized distributions, Journal of Statistical Computation and Simulation 81 (2011) 883-898

G. M. Cordeiro, E. M. M. Ortega, D. C. C. da Cunha, The exponentiated generalized class of distributions, Journal of Data Science 11 (2013) 1-27

G. M. Cordeiro, E. M. M. Ortega, G. Silva, The beta extended Weibull family, Journal of Probability and Statistical Science 10 (2012) 15-40

N. Eugene, C. Lee, F. Famoye, Beta-normal distribution and its applications, Communications in Statistics---Theory and Methods, 31 (2002) 497-512

R. C. Gupta, P. L. Gupta, R. D. Gupta, Modeling failure time data by Lehman alternatives, Communications in Statistics---Theory and Methods 27 (1998) 887-904

A. J. Lemonte, W. Barreto-Souza, G. M. Cordeiro, The exponentiated Kumaraswamy distribution and its log-transform, Brazilian Journal of Probability and Statistics 27 (2013) 31-53

A. W. Marshall, I. Olkin, A new method for adding a parameter to a family of distributions with application to the exponential and Weibull families, Biometrika 84 (1997) 641-652

S. Nadarajah, Newdistns: An R Package for new families of distributions, submitted

S. Nadarajah, V. G. Cancho, E. M. M. Ortega, The geometric exponential Poisson distribution, Stat Methods Appl 22 (2013a) 355-380

S. Nadarajah, V. Nassiri, A. Mohammadpour, Truncated-exponential skew-symmetric distributions, Statistics, 2013b, to appear

S. Nadarajah, M. Teimouri, S. H. Shih, Modified beta distributions, Sankhya, 2013c, to appear

M. M. Ristic, S. Nadarajah, A new lifetime distribution, Journal of Statistical Computation and Simulation, doi: 10.1080/00949655.2012.697163

H. Torabi, N. H. Montazeri, The gamma uniform distribution and its applications, Kybernetika 48 (2012) 16-30

K. Zografos, N. Balakrishnan, On families of beta- and generalized gamma-generated distributions and associated inference, Statistical Methodology 6 (2009) 344-362}
\keyword{package}

==> Newdistns_2.0.tar.gz: Newdistns/man/Newdistns-package.Rd <==
\name{Newdistns-package}
\alias{Newdistns-package}
\alias{Newdistns}
\docType{package}
\title{
Computes Pdf, Cdf, Quantile, Random Numbers and Measures of Inference for 19 General Families of Distributions
}
\description{Computes the probability density function, cumulative distribution function, quantile function, random numbers and measures of inference for the following general families of  distributions (each family defined in terms of an arbitrary cdf G): Marshall Olkin G distributions due to Marshall and Olkin  (1997), exponentiated G distributions due to Gupta et al. (1998), beta G distributions due to Eugene et al. (2002), gamma G distributions due to Zografos and Balakrishnan (2009), Kumaraswamy G distributions due to Cordeiro and Castro (2011), generalized beta G distributions due to Alexander et al. (2012),
beta extended G distributions due to Cordeiro et al. (2012), gamma G distributions due to Ristic and Balakrishnan (2012), gamma uniform G distributions due to Torabi and Montazeri (2012), beta exponential G distributions due to Alzaatreh et al. (2013), Weibull G distributions also due to Alzaatreh et al. (2013), log gamma G I distributions due to Amini et al. (2013), log gamma G II distributions also due to Amini et al. (2013), exponentiated generalized G distributions due to Cordeiro et al. (2013), exponentiated Kumaraswamy G distributions due to Lemonte et al. (2013), geometric exponential Poisson G distributions due to Nadarajah et al. (2013a), truncated-exponential skew-symmetric G distributions due to Nadarajah et al. (2013b), modified beta G distributions due to Nadarajah et al. (2013c), and exponentiated exponential Poisson G distributions due to Ristic and Nadarajah (2013).}
\details{
\tabular{ll}{
Package: \tab Newdistns\cr
Type: \tab Package\cr
Version: \tab 2.0\cr
Date: \tab 2015-02-27\cr
License: \tab GPL(>=2)
}
probability density function, cumulative distribution function, quantile function, random numbers and measures of inference
}
\author{Saralees Nadarajah, Ricardo Rocha

Maintainer: Saralees Nadarajah <Saralees.Nadarajah@manchester.ac.uk>
}
\references{C. Alexander, G. M. Cordeiro, E. M. M. Ortega, Generalized beta-generated distributions, Computational Statistics and Data Analysis 56 (2012) 1880-1897

A. Alzaatreh, C. Lee, F. Famoye, A new method for generating families of continuous distributions, METRON 71 (2013) 63-79

M. Amini, S. M. T. K. MirMostafaee, J. Ahmadi, Log-gamma-generated families of distributions, Statistics, 2013, doi: 10.1080/02331888.2012.748775

G. M. Cordeiro, M. Castro, A new family of generalized distributions, Journal of Statistical Computation and Simulation 81 (2011) 883-898

G. M. Cordeiro, E. M. M. Ortega, D. C. C. da Cunha, The exponentiated generalized class of distributions, Journal of Data Science 11 (2013) 1-27

G. M. Cordeiro, E. M. M. Ortega, G. Silva, The beta extended Weibull family, Journal of Probability and Statistical Science 10 (2012) 15-40

N. Eugene, C. Lee, F. Famoye, Beta-normal distribution and its applications, Communications in Statistics---Theory and Methods, 31 (2002) 497-512

R. C. Gupta, P. L. Gupta, R. D. Gupta, Modeling failure time data by Lehman alternatives, Communications in Statistics---Theory and Methods 27 (1998) 887-904

A. J. Lemonte, W. Barreto-Souza, G. M. Cordeiro, The exponentiated Kumaraswamy distribution and its log-transform, Brazilian Journal of Probability and Statistics 27 (2013) 31-53

A. W. Marshall, I. Olkin, A new method for adding a parameter to a family of distributions with application to the exponential and Weibull families, Biometrika 84 (1997) 641-652

S. Nadarajah, Newdistns: An R Package for new families of distributions, submitted

S. Nadarajah, V. G. Cancho, E. M. M. Ortega, The geometric exponential Poisson distribution, Stat Methods Appl 22 (2013a) 355-380

S. Nadarajah, V. Nassiri, A. Mohammadpour, Truncated-exponential skew-symmetric distributions, Statistics, 2013b, to appear

S. Nadarajah, M. Teimouri, S. H. Shih, Modified beta distributions, Sankhya, 2013c, to appear

M. M. Ristic, S. Nadarajah, A new lifetime distribution, Journal of Statistical Computation and Simulation, doi: 10.1080/00949655.2012.697163

H. Torabi, N. H. Montazeri, The gamma uniform distribution and its applications, Kybernetika 48 (2012) 16-30

K. Zografos, N. Balakrishnan, On families of beta- and generalized gamma-generated distributions and associated inference, Statistical Methodology 6 (2009) 344-362}
\keyword{package}
